@@ -4,7 +4,7 @@ use warnings;
 
 package Test::EOF;
 
-our $VERSION = '0.0802'; # VERSION
+our $VERSION = '0.0803'; # VERSION
 # ABSTRACT: Check correct end of files in a project.
 
 use Cwd qw/cwd/;
@@ -166,9 +166,24 @@ __END__
 
 Test::EOF - Check correct end of files in a project.
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-test-eof"><img src="https://api.travis-ci.org/Csson/p5-test-eof.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-test-eof.svg?branch=master)](https://travis-ci.org/Csson/p5-test-eof)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.0802, released 2015-02-11.
+Version 0.0803, released 2015-11-25.
 
 =head1 SYNOPSIS
 
@@ -238,19 +253,6 @@ L<Test::More>
 
 =back
 
-=head1 AUTHOR
-
-Erik Carlsson E<lt>info@code301.comE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2014- Erik Carlsson
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SOURCE
 
 L<https://github.com/Csson/p5-test-eof>
@@ -265,7 +267,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
